@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[4]:
+# In[2]:
 
 
 
@@ -85,10 +85,16 @@ def start_server(debug = False):
                         print ('Data received from client')
 
 
-                except:
+                except Exception as g:
                     if debug == True:
                         print("ERROR OR CLIENT DONE")
-                    pass
+                        print(g)
+                        resultsize = str(len(pickle.dumps(g,-1)))
+
+                        conn.send(pickle.dumps(resultsize))
+
+                        conn.send(result)
+                        pass
 
 
    
@@ -178,3 +184,9 @@ def do(code):
 
 
 
+
+# In[ ]:
+
+
+
+
